@@ -38,8 +38,8 @@ function (formula, data, model = c("all"), nperm, quantitative = is.quantitative
         stop("interaction term is not implemented")
 
     colSNPs <- attr(data, "colSNPs")
-    if (is.vector(colSNPs) & length(colSNPs) > 1) 
-        dataSNPs <- data[control.missing, colSNPs]
+    if (is.vector(colSNPs) & length(colSNPs) > 0) 
+        dataSNPs <- data[control.missing, colSNPs, drop=FALSE]
     else stop("data should have an attribute called 'colSNPs'. Try again 'setupSNP' function")
 
     type <- charmatch(model, c("codominant", "dominant", "recessive", 
